netapp_ontap.models.application_template1 API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.application_template1`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ApplicationTemplate1Schema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ApplicationTemplate1 object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `links GET`

    The links field of the application_template1.

  `name GET POST`

    The name of the template that was used to provision this application.

  `protocol GET`

    The protocol access of the template that was used to provision this application.

    Valid choices:

    - nas
    - nvme
    - s3
    - san
  `version GET`

    The version of the template that was used to provision this application. The template version changes only if the layout of the application changes over time. For example, redo logs in Oracle RAC templates were updated and provisioned differently in DATA ONTAP 9.3.0 compared to prior releases, so the version number was increased. If layouts change in the future, the changes will be documented along with the corresponding version numbers.